# Table of Contents

- [fact-sheet-permissions](<./fact-sheet-permissions.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Fact Sheet Permissions](<./Fact-Sheet-Permissions.md>)
  - [Overview](<./Fact-Sheet-Permissions/Overview.md>)
  - [Best Practices](<./Fact-Sheet-Permissions/Best-Practices.md>)
  - [Configuring Fact Sheet Permissions](<./Fact-Sheet-Permissions/Configuring-Fact-Sheet-Permissions.md>)
  - [Permissions Overview](<./Fact-Sheet-Permissions/Permissions-Overview.md>)
  - [General Permissions](<./Fact-Sheet-Permissions/General-Permissions.md>)
  - [Global Permissions](<./Fact-Sheet-Permissions/Global-Permissions.md>)
  - [Permissions for Subscription Types](<./Fact-Sheet-Permissions/Permissions-for-Subscription-Types.md>)
  - [Field Permissions](<./Fact-Sheet-Permissions/Field-Permissions.md>)
  - [Relation Permissions](<./Fact-Sheet-Permissions/Relation-Permissions.md>)
  - [Advanced Permissions](<./Fact-Sheet-Permissions/Advanced-Permissions.md>)
  - [Subscription-Based Permissions](<./Fact-Sheet-Permissions/Subscription-Based-Permissions.md>)
  - [Tag-Based Permissions](<./Fact-Sheet-Permissions/Tag-Based-Permissions.md>)
